==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { LineSeriesDescription } from "./LineSeriesDescription";
/**
 * @hidden
 */
export let LineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class LineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (LineSeriesDescriptionMetadata.a == null) {
                LineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LineSeriesDescriptionMetadata.c(LineSeriesDescriptionMetadata.a);
            }
            if (a.k(LineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(LineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            LineSeriesDescriptionMetadata.b(a);
            a.ac("LineSeries", () => new LineSeriesDescription());
            a.ab("LineSeries", LineSeriesDescriptionMetadata.a);
        }
    }
    LineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(LineSeriesDescriptionMetadata, 'LineSeriesDescriptionMetadata');
    LineSeriesDescriptionMetadata.a = null;
    return LineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/LineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { LineSeriesDescription } from "./LineSeriesDescription";
/**
 * @hidden
 */
export let LineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class LineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (LineSeriesDescriptionMetadata.a == null) {
                LineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LineSeriesDescriptionMetadata.c(LineSeriesDescriptionMetadata.a);
            }
            if (a.k(LineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(LineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            LineSeriesDescriptionMetadata.b(a);
            a.ae("LineSeries", () => new LineSeriesDescription());
            a.ad("LineSeries", LineSeriesDescriptionMetadata.a);
        }
    }
    LineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(LineSeriesDescriptionMetadata, 'LineSeriesDescriptionMetadata');
    LineSeriesDescriptionMetadata.a = null;
    return LineSeriesDescriptionMetadata;
})();
